**Example 1: 基线检测概要**



Input: 

```
tccli cwp DescribeBaselineDetectOverview --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "LatestPassCount": 0,
        "HostCount": 8,
        "LatestNotPassCount": 0,
        "PolicyCount": 18,
        "PassRate": 0,
        "RequestId": "xx",
        "ItemCount": 2955
    }
}
```

